package
Version:
v0.2.0
Opens a new window with list of versions in this module.
Published: Dec 21, 2016
License: Apache-2.0
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type TokenRequest struct {
Project string `json:"project"`
Username string `json:"username"`
Password string `json:"password"`
Service string `json:"service"`
Labels map[string]string `json:"labels"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.